@@ -11,49 +11,28 @@ use strict;
 use warnings;
 package Template::ShowStartStop;
 BEGIN {
-  $Template::ShowStartStop::VERSION = '0.11';
+  $Template::ShowStartStop::VERSION = '0.12';
 }
 use Moose;
 use namespace::autoclean;
 
 extends 'Template::Context';
+with 'MooseX::Template::Context::Role::ShowStartStop';
 
-override 'process' => sub {
-	my $self = shift;
-	my ( $template ) = @_;
-
-	my $template_id
-		# conditional                        # set $template to
-		= ref($template) eq 'Template::Document' ? $template->name
-		: ref($template) eq 'ARRAY'              ? join( ' + ', @{$template} )
-		: ref($template) eq 'SCALAR'             ? '(evaluated block)'
-		:                                          $template
-		;
-
-	my $processed_data = super();
-
-	my $output
-		= "<!-- START: process $template_id -->\n"
-		. "$processed_data"
-		. "<!-- STOP:  process $template_id -->\n"
-		;
-
-	return $output;
-};
 __PACKAGE__->meta->make_immutable(inline_constructor => 0);
 1;
-# ABSTRACT: Display where template's start and stop
+# ABSTRACT: Display where templates start and stop
 
 __END__
 =pod
 
 =head1 NAME
 
-Template::ShowStartStop - Display where template's start and stop
+Template::ShowStartStop - Display where templates start and stop
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -87,7 +66,7 @@ output, which you can easily grep for.  The nesting level is also shown.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on 
+Please report any bugs or feature requests on
 L<http://github.com/xenoterracide/Template-ShowStartStop/issues>
 as I'm not fond of RT.
 
@@ -107,7 +86,7 @@ and to Gavin Estey for the original Template::Timer code that this is based on.
 
 =head1 AUTHOR
 
-  Caleb Cushing <xenoterracide@gmail.com>
+Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
